@@ -53,9 +53,9 @@ public:
      *  @param node The node to observe */
     void showNode(Akregator::TreeNode *node);
 
-    Q_REQUIRED_RESULT QSize sizeHint() const override;
+    [[nodiscard]] QSize sizeHint() const override;
 
-    Q_REQUIRED_RESULT qreal zoomFactor() const;
+    [[nodiscard]] qreal zoomFactor() const;
 
     Akregator::ArticleViewerWebEngineWidgetNg *articleViewerWidgetNg() const;
 
@@ -101,9 +101,9 @@ protected Q_SLOTS:
 
     void slotArticlesListed(KJob *job);
 
-    void slotArticlesUpdated(Akregator::TreeNode *node, const QVector<Akregator::Article> &list);
-    void slotArticlesAdded(Akregator::TreeNode *node, const QVector<Akregator::Article> &list);
-    void slotArticlesRemoved(Akregator::TreeNode *node, const QVector<Akregator::Article> &list);
+    void slotArticlesUpdated(Akregator::TreeNode *node, const QList<Akregator::Article> &list);
+    void slotArticlesAdded(Akregator::TreeNode *node, const QList<Akregator::Article> &list);
+    void slotArticlesRemoved(Akregator::TreeNode *node, const QList<Akregator::Article> &list);
 
     // from ArticleViewer
 private:
@@ -132,7 +132,7 @@ private:
     QPointer<TreeNode> m_node;
     QPointer<ArticleListJob> m_listJob;
     Article m_article;
-    QVector<Article> m_articles;
+    QList<Article> m_articles;
     QUrl m_link;
     std::vector<QSharedPointer<const Filters::AbstractMatcher>> m_filters;
     enum ViewMode { NormalView, CombinedView, SummaryView };
